# Title: Measuring perceived fitness interdependence between humans and non-humans

# Authors: Katie Lee, Darragh Hare, Bernd Blossey

######################################################################################
# Install and load packages
install.packages("pacman")
library(pacman)
pacman::p_load(dplyr, tidyverse, psych, corrplot, GPArotation, nFactors, lavaan, 
       sem, semPlot, ggrepel)

# Read the data
PFI_cons_ethics <- read.csv("Lee_et_al_2023-Measuring_perceived_fitness_interdependence-Data.csv")

###### Survey items ##################################################################
# P1: When [target] become more scarce, that is...
# P2: When people behave kindly towards [target], that is...
# P3: When people harm [target], that is...
# P5: [Target] and I rise and fall together
# P6: What is beneficial to [target] is beneficial to me, and what is harmful to [target] is harmful to me
# P7: When [target] thrive, I feel good
# P8: A world without [target] would be worse for me
# P9: [Target] and I have different fates
# P10: I feel detached from [target]
# C1: [Target] deserve to be protected from harm
# C2: [Target] should not be treated with care and compassion
# C3: [Target] deserve to be treated fairly
# C4: I have sympathy for [target]
# C5: Harming [target] is morally right
# C6: People are entitled to harm [target]
# C7: Killing [target] is morally wrong
# C8: It would be important to protect [target] from extinction
# C9: People should deny moral concern for [target]
# C10: I feel no personal sense of responsibility to help [target]
# C11: One of the worst things a person could do is to harm [target]
######################################################################################

# Clean up the data
## Exclude participants whose response times are 4 times the median (200s)
200*4 # Exclude participants whose response time > 800 seconds
PFI_cons_ethics <- 
  PFI_cons_ethics %>% filter(duration < 800)

## Exclude straight-liners from the data set (provided identical responses to P1-P3 and P5-C11)
PFI_cons_ethics<-PFI_cons_ethics[!(PFI_cons_ethics$participant=="307" | 
                                     PFI_cons_ethics$participant=="607" | 
                                     PFI_cons_ethics$participant=="622" | 
                                     PFI_cons_ethics$participant=="623" | 
                                     PFI_cons_ethics$participant=="648"),]

# Assign data types for each variable in the data set
PFI_cons_ethics$participant <- as.factor(PFI_cons_ethics$participant)
PFI_cons_ethics$gender <- as.factor(PFI_cons_ethics$gender)
PFI_cons_ethics$ethnic <- as.factor(PFI_cons_ethics$ethnic)
PFI_cons_ethics$zip.code <- as.factor(PFI_cons_ethics$zip.code)
PFI_cons_ethics$S1 <- as.factor(PFI_cons_ethics$S1)
PFI_cons_ethics$P1 <- as.factor(PFI_cons_ethics$P1)
PFI_cons_ethics$P2 <- as.factor(PFI_cons_ethics$P2)
PFI_cons_ethics$P3 <- as.factor(PFI_cons_ethics$P3)
PFI_cons_ethics$P4.A <- as.factor(PFI_cons_ethics$P4.A)
PFI_cons_ethics$P5 <- as.factor(PFI_cons_ethics$P5)
PFI_cons_ethics$P6 <- as.factor(PFI_cons_ethics$P6)
PFI_cons_ethics$P7 <- as.factor(PFI_cons_ethics$P7)
PFI_cons_ethics$P8 <- as.factor(PFI_cons_ethics$P8)
PFI_cons_ethics$P9 <- as.factor(PFI_cons_ethics$P9)
PFI_cons_ethics$P10 <- as.factor(PFI_cons_ethics$P10)
PFI_cons_ethics$C1 <- as.factor(PFI_cons_ethics$C1)
PFI_cons_ethics$C2 <- as.factor(PFI_cons_ethics$C2)
PFI_cons_ethics$C3 <- as.factor(PFI_cons_ethics$C3)
PFI_cons_ethics$C4 <- as.factor(PFI_cons_ethics$C4)
PFI_cons_ethics$C5 <- as.factor(PFI_cons_ethics$C5)
PFI_cons_ethics$C6 <- as.factor(PFI_cons_ethics$C6)
PFI_cons_ethics$C7 <- as.factor(PFI_cons_ethics$C7)
PFI_cons_ethics$C8 <- as.factor(PFI_cons_ethics$C8)
PFI_cons_ethics$C9 <- as.factor(PFI_cons_ethics$C9)
PFI_cons_ethics$C10 <- as.factor(PFI_cons_ethics$C10)
PFI_cons_ethics$C11 <- as.factor(PFI_cons_ethics$C11)
PFI_cons_ethics$C12.A <- as.factor(PFI_cons_ethics$C12.A)

# Make a copy of the data set
PFI_cons_ethics_2 <- PFI_cons_ethics

# Code/reverse-code (rc) the response items for PFI on a 1-7 Likert scale
PFI_cons_ethics_2$P1.rc <- as.factor(recode( # P1 (reverse-coded item)
  PFI_cons_ethics_2$P1,
  "Very beneficial to me"= 1,
  "Beneficial to me"= 2,
  "Somewhat beneficial to me"= 3,
  "Neither harmful nor beneficial to me"= 4,
  "Somewhat harmful to me"= 5,
  "Harmful to me"= 6,
  "Very harmful to me"= 7
))

# Change P1 to an ordered factor
PFI_cons_ethics_2$P1.rc <- ordered(PFI_cons_ethics_2$P1.rc, levels = 1:7)

PFI_cons_ethics_2$P2.r <- as.factor(recode( # P2
  PFI_cons_ethics_2$P2,
  "Very beneficial to me"= 7,
  "Beneficial to me"= 6,
  "Somewhat beneficial to me"= 5,
  "Neither harmful nor beneficial to me"= 4,
  "Somewhat harmful to me"= 3,
  "Harmful to me"= 2,
  "Very harmful to me"= 1
))

# Change P2 to an ordered factor
PFI_cons_ethics_2$P2.r <- ordered(PFI_cons_ethics_2$P2.r, levels = 1:7)

PFI_cons_ethics_2$P3.rc <- as.factor(recode( # P3 (reverse-coded item)
  PFI_cons_ethics_2$P3,
  "Very beneficial to me"= 1,
  "Beneficial to me"= 2,
  "Somewhat beneficial to me"= 3,
  "Neither harmful nor beneficial to me"= 4,
  "Somewhat harmful to me"= 5,
  "Harmful to me"= 6,
  "Very harmful to me"= 7
))

# Change P3 to an ordered factor
PFI_cons_ethics_2$P3.rc <- ordered(PFI_cons_ethics_2$P3.rc, levels = 1:7)

# P4 is an attention check (select "harmful to me")

PFI_cons_ethics_2$P5.r <- as.factor(recode( # P5
  PFI_cons_ethics_2$P5,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change P5 to an ordered factor
PFI_cons_ethics_2$P5.r <- ordered(PFI_cons_ethics_2$P5.r, levels = 1:7)

PFI_cons_ethics_2$P6.r <- as.factor(recode( # P6
  PFI_cons_ethics_2$P6,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change P6 to an ordered factor
PFI_cons_ethics_2$P6.r <- ordered(PFI_cons_ethics_2$P6.r, levels = 1:7)

PFI_cons_ethics_2$P7.r <- as.factor(recode( # P7
  PFI_cons_ethics_2$P7,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change P7 to an ordered factor
PFI_cons_ethics_2$P7.r <- ordered(PFI_cons_ethics_2$P7.r, levels = 1:7)

PFI_cons_ethics_2$P8.r <- as.factor(recode( # P8
  PFI_cons_ethics_2$P8,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change P8 to an ordered factor
PFI_cons_ethics_2$P8.r <- ordered(PFI_cons_ethics_2$P8.r, levels = 1:7)

PFI_cons_ethics_2$P9.rc <- as.factor(recode( # P9 (reverse-coded item)
  PFI_cons_ethics_2$P9,
  "Strongly agree"= 1,
  "Agree"= 2,
  "Somewhat agree"= 3,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 5,
  "Disagree"= 6,
  "Strongly disagree"= 7
))

# Change P9 to an ordered factor
PFI_cons_ethics_2$P9.rc <- ordered(PFI_cons_ethics_2$P9.rc, levels = 1:7)

PFI_cons_ethics_2$P10.rc <- as.factor(recode( # P10 (reverse-coded item)
  PFI_cons_ethics_2$P10,
  "Strongly agree"= 1,
  "Agree"= 2,
  "Somewhat agree"= 3,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 5,
  "Disagree"= 6,
  "Strongly disagree"= 7
))

# Change P10 to an ordered factor
PFI_cons_ethics_2$P10.rc <- ordered(PFI_cons_ethics_2$P10.rc, levels = 1:7)

# Code/reverse-code (rc) the response items for conservation ethics on a 1-7 Likert scale
PFI_cons_ethics_2$C1.r <- as.factor(recode( # C1
  PFI_cons_ethics_2$C1,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change C1 to an ordered factor
PFI_cons_ethics_2$C1.r <- ordered(PFI_cons_ethics_2$C1.r, levels = 1:7)

PFI_cons_ethics_2$C2.rc <- as.factor(recode( # C2 (reverse-coded item)
  PFI_cons_ethics_2$C2,
  "Strongly agree"= 1,
  "Agree"= 2,
  "Somewhat agree"= 3,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 5,
  "Disagree"= 6,
  "Strongly disagree"= 7
))

# Change C2 to an ordered factor
PFI_cons_ethics_2$C2.rc <- ordered(PFI_cons_ethics_2$C2.rc, levels = 1:7)

PFI_cons_ethics_2$C3.r <- as.factor(recode( # C3
  PFI_cons_ethics_2$C3,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change C3 to an ordered factor
PFI_cons_ethics_2$C3.r <- ordered(PFI_cons_ethics_2$C3.r, levels = 1:7)

PFI_cons_ethics_2$C4.r <- as.factor(recode( # C4
  PFI_cons_ethics_2$C4,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change C4 to an ordered factor
PFI_cons_ethics_2$C4.r <- ordered(PFI_cons_ethics_2$C4.r, levels = 1:7)

PFI_cons_ethics_2$C5.rc <- as.factor(recode( # C5 (reverse-coded item)
  PFI_cons_ethics_2$C5,
  "Strongly agree"= 1,
  "Agree"= 2,
  "Somewhat agree"= 3,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 5,
  "Disagree"= 6,
  "Strongly disagree"= 7
))

# Change C5 to an ordered factor
PFI_cons_ethics_2$C5.rc <- ordered(PFI_cons_ethics_2$C5.rc, levels = 1:7)

PFI_cons_ethics_2$C6.rc <- as.factor(recode( # C6 (reverse-coded item)
  PFI_cons_ethics_2$C6,
  "Strongly agree"= 1,
  "Agree"= 2,
  "Somewhat agree"= 3,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 5,
  "Disagree"= 6,
  "Strongly disagree"= 7
))

# Change C6 to an ordered factor
PFI_cons_ethics_2$C6.rc <- ordered(PFI_cons_ethics_2$C6.rc, levels = 1:7)

PFI_cons_ethics_2$C7.r <- as.factor(recode( # C7
  PFI_cons_ethics_2$C7,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change C7 to an ordered factor
PFI_cons_ethics_2$C7.r <- ordered(PFI_cons_ethics_2$C7.r, levels = 1:7)

PFI_cons_ethics_2$C8.r <- as.factor(recode( # C8
  PFI_cons_ethics_2$C8,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change C8 to an ordered factor
PFI_cons_ethics_2$C8.r <- ordered(PFI_cons_ethics_2$C8.r, levels = 1:7)

PFI_cons_ethics_2$C9.rc <- as.factor(recode( # C9 (reverse-coded item)
  PFI_cons_ethics_2$C9,
  "Strongly agree"= 1,
  "Agree"= 2,
  "Somewhat agree"= 3,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 5,
  "Disagree"= 6,
  "Strongly disagree"= 7
))

# Change C9 to an ordered factor
PFI_cons_ethics_2$C9.rc <- ordered(PFI_cons_ethics_2$C9.rc, levels = 1:7)

PFI_cons_ethics_2$C10.rc <- as.factor(recode( # C10 (reverse-coded item)
  PFI_cons_ethics_2$C10,
  "Strongly agree"= 1,
  "Agree"= 2,
  "Somewhat agree"= 3,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 5,
  "Disagree"= 6,
  "Strongly disagree"= 7
))

# Change C10 to an ordered factor
PFI_cons_ethics_2$C10.rc <- ordered(PFI_cons_ethics_2$C10.rc, levels = 1:7)

PFI_cons_ethics_2$C11.r <- as.factor(recode( # C11
  PFI_cons_ethics_2$C11,
  "Strongly agree"= 7,
  "Agree"= 6,
  "Somewhat agree"= 5,
  "Neither agree nor disagree"= 4,
  "Somewhat disagree"= 3,
  "Disagree"= 2,
  "Strongly disagree"= 1
))

# Change C11 to an ordered factor
PFI_cons_ethics_2$C11.r <- ordered(PFI_cons_ethics_2$C11.r, levels = 1:7)

# C12 is an attention check (select "agree")

# Remove original P1 - C12 columns
PFI_cons_ethics_2 <- PFI_cons_ethics_2[, -c(8:29)]

###### Exploratory factor analyses for all target species ############################

###### Exploratory factor analyses for PFI scale #####################################
# Remove all columns but P1.rc - P10.rc
PFI_cons_ethics_fac <- PFI_cons_ethics_2[, -c(1:7, 17:27)]

# Re-code PFI items as numeric for analysis
PFI_cons_ethics_fac$P1.rc <- as.numeric(PFI_cons_ethics_fac$P1.rc)
PFI_cons_ethics_fac$P2.r <- as.numeric(PFI_cons_ethics_fac$P2.r)
PFI_cons_ethics_fac$P3.rc <- as.numeric(PFI_cons_ethics_fac$P3.rc)
PFI_cons_ethics_fac$P5.r <- as.numeric(PFI_cons_ethics_fac$P5.r)
PFI_cons_ethics_fac$P6.r <- as.numeric(PFI_cons_ethics_fac$P6.r)
PFI_cons_ethics_fac$P7.r <- as.numeric(PFI_cons_ethics_fac$P7.r)
PFI_cons_ethics_fac$P8.r <- as.numeric(PFI_cons_ethics_fac$P8.r)
PFI_cons_ethics_fac$P9.rc <- as.numeric(PFI_cons_ethics_fac$P9.rc)
PFI_cons_ethics_fac$P10.rc <- as.numeric(PFI_cons_ethics_fac$P10.rc)

# Check sample size
dim(PFI_cons_ethics_fac) # sample size is > 300

# Check sampling adequacy (Kaiser-Meyer-Olkin)
KMO(cor(PFI_cons_ethics_fac)) # overall KMO = 0.89 and individual KMOs for each item are all > 0.75

# Check summary statistics for each item
barplot(table(PFI_cons_ethics_fac$P1.rc)) # P1
summary(PFI_cons_ethics_fac$P1.rc)
sd(PFI_cons_ethics_fac$P1.rc)

barplot(table(PFI_cons_ethics_fac$P2.r)) # P2
summary(PFI_cons_ethics_fac$P2.r)
sd(PFI_cons_ethics_fac$P2.r)

barplot(table(PFI_cons_ethics_fac$P3.rc)) # P3
summary(PFI_cons_ethics_fac$P3.rc)
sd(PFI_cons_ethics_fac$P3.rc)

barplot(table(PFI_cons_ethics_fac$P5.r)) # P5
summary(PFI_cons_ethics_fac$P5.r)
sd(PFI_cons_ethics_fac$P5.r)

barplot(table(PFI_cons_ethics_fac$P6.r)) # P6
summary(PFI_cons_ethics_fac$P6.r)
sd(PFI_cons_ethics_fac$P6.r)

barplot(table(PFI_cons_ethics_fac$P7.r)) # P7
summary(PFI_cons_ethics_fac$P7.r)
sd(PFI_cons_ethics_fac$P7.r)

barplot(table(PFI_cons_ethics_fac$P8.r)) # P8
summary(PFI_cons_ethics_fac$P8.r)
sd(PFI_cons_ethics_fac$P8.r)

barplot(table(PFI_cons_ethics_fac$P9.rc)) #P9
summary(PFI_cons_ethics_fac$P9.rc)
sd(PFI_cons_ethics_fac$P9.rc)

barplot(table(PFI_cons_ethics_fac$P10.rc)) #P10
summary(PFI_cons_ethics_fac$P10.rc)
sd(PFI_cons_ethics_fac$P10.rc)

# Check correlation between items
cor(PFI_cons_ethics_fac)
R <- cor(PFI_cons_ethics_fac)
round(R, digits=3) # most correlations >0.3 and all <0.8

# Test whether the correlation matrix is significantly different from the identity matrix using Bartlett's test
cortest.bartlett(R, n=nrow(PFI_cons_ethics_fac)) # p < 0.05

# Check the determinant to see whether items are perfectly correlated (det = 0)
det(R) # det > 0.00001

# Perform factor extraction
## Compute eigenvalues and use screeplots to determine the number of factors to extract
eig <- eigen(R)
eig$values
plot(eig$values, type="b", main="Screeplot", xlab="Number of Components", ylab="Eigenvalue")
abline(a=1, b=0, col="red")

scree <- scree(PFI_cons_ethics_fac)
scree # screeplot suggests extracting 1 factor

## Compare screeplot results with parallel analysis results
parallel <- fa.parallel(PFI_cons_ethics_fac,fm="pa",fa="fa")
parallel # parallel analysis suggests extracting 2 factors

## Extract 1 factor from initial set of PFI items and examine fit of a one-factor solution
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=1)
fa_pa$e.values
fa_pa

## Extract 2 factors from initial set of items and examine fit of a two-factor solution
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=2)
fa_pa$e.values
fa_pa # Two-factor solution is the best fit for the data

## Extract 3 factors from initial set of items and examine fit of a three-factor solution
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=3)
fa_pa$e.values
fa_pa

### Analysis for a two-factor solution

# Print factor loadings
fa_pa$loadings # uses a cut-off of 0.1
print(fa_pa$loadings, cut=NULL) # removes cut-off
fa.sort(fa_pa$loadings) # sorts based on first factor

# Create a factor plot
plot(fa_pa) 
plot(fa_pa, labels=colnames(R), cex=0.8, choose=c(1,2))

# Create a factor diagram to see which factor loads highest onto each item
fa.diagram(fa_pa) # uses a cut-off of 0.3
fa.diagram(fa_pa, cut=0) # removes cut-off
fa.diagram(fa_pa, cut=0, simple=FALSE) # shows full model

# Perform factor rotation (orthogonal - factors are independent, oblique - factors are correlated)
fa_pa_orth <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="varimax", fm="pa", nfactors=2) # orthogonal rotation (varimax)
print(fa_pa_orth$loadings) # factor loadings
plot(fa_pa_orth, labels=colnames(R), cex=0.8, choose=c(1,2)) # factor plot
fa.diagram(fa_pa_orth, cut=0) # factor diagram

fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2) # oblique rotation (oblimin)
print(fa_pa_obq$loadings, cut = NULL) # factor loadings
plot(fa_pa_obq, labels=colnames(R), cex=0.8, choose=c(1,2)) # factor plot
fa.diagram(fa_pa_obq, cut=0)  # factor diagram

# Estimate factor scores for both types of rotation
fa_pa_orth <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="varimax", fm="pa", nfactors=2, scores="regression") # orthogonal
fa_pa_orth$weights # score coefficients, note the order
scores_orth <- predict(fa_pa_orth, data=PFI_cons_ethics_fac) # factor scores
plot(data.frame(scores_orth)) # score plot

fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2, scores="regression") # oblique
fa_pa_obq$weights # score coefficients, note the order
scores_obq <- predict(fa_pa_obq, data=PFI_cons_ethics_fac) # factor scores
plot(data.frame(scores_obq)) # score plot

# Assume factors are somewhat correlated, so use oblique rotation
# Check fit statistics and model reliability
summary(fa_pa_obq)
Rresid <- resid(fa_pa_obq)
corrplot(Rresid, method="number", number.cex=0.7)

# Assess total/per-factor internal reliability using Cronbach's alpha and McDonald's omega
fa.diagram(fa_pa_obq, cut=0)

PA1 <- c("P3.rc", "P1.rc", "P2.r", "P7.r", "P8.r", "P6.r", "P10.rc")
alpha(PFI_cons_ethics_fac[, PA1]) # alpha > 0.8

PA2 <- c("P5.r", "P9.rc")
alpha(PFI_cons_ethics_fac[, PA2])

omega(PFI_cons_ethics_fac) # omega > 0.8

# Repeat exploratory factor analysis with a loading cut-off of 0.5 (following the same process as above)
## 1st repeat: remove P6.r, P10.rc, and P9.rc
## 2nd repeat: remove P8.r

PFI_cons_ethics_fac <- subset(PFI_cons_ethics_fac, select = -c(P6.r, P10.rc, P9.rc)) # 1st repeat
PFI_cons_ethics_fac <- subset(PFI_cons_ethics_fac, select = -c(P8.r)) # 2nd repeat

# Check sample size
dim(PFI_cons_ethics_fac)

# Check sampling adequacy (Kaiser-Meyer-Olkin)
KMO(cor(PFI_cons_ethics_fac)) # KMO > 0.8

# Check correlation between items
cor(PFI_cons_ethics_fac) # most correlations > 0.3 and < 0.8
R <- cor(PFI_cons_ethics_fac)
round(R, digits=3)

# Bartlett's test
cortest.bartlett(R, n=nrow(PFI_cons_ethics_fac)) # p < 0.05

# Determinant
det(R) # det > 0.00001

# Factor extraction
## Compute eigenvalues and use screeplots to determine the number of factors to extract
eig <- eigen(R)
eig$values
plot(eig$values, type="b", main="Screeplot", xlab="Number of Components", ylab="Eigenvalue")
abline(a=1, b=0, col="red")

scree <- scree(PFI_cons_ethics_fac)
scree # screeplot suggests extracting 1 factor

## Compare screeplot results with parallel analysis results
parallel <- fa.parallel(PFI_cons_ethics_fac,fm="pa",fa="fa")
parallel # parallel analysis suggests extracting 2 factors

## Extract 2 factors (1-factor solution was not a good fit)
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=2)
fa_pa$e.values
fa_pa

# Print factor loadings
fa_pa$loadings
print(fa_pa$loadings, cut=NULL)
fa.sort(fa_pa$loadings)

# Factor plot
plot(fa_pa) 
plot(fa_pa, labels=colnames(R), cex=0.8, choose=c(2))

# Factor diagram
fa.diagram(fa_pa)
fa.diagram(fa_pa, cut=0)
fa.diagram(fa_pa, cut=0, simple=FALSE)

# Factor rotation
# Assume the factors are somewhat correlated, so use oblique rotation
fa_pa_orth <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="varimax", fm="pa", nfactors=2) # orthogonal rotation
print(fa_pa_orth$loadings)
plot(fa_pa_orth, labels=colnames(R), cex=0.8, choose=c(1,2))
fa.diagram(fa_pa_orth, cut=0)

fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2) # oblique rotation
print(fa_pa_obq$loadings, cut = NULL)
plot(fa_pa_obq, labels=colnames(R), cex=0.8, choose=c(1,2))
fa.diagram(fa_pa_obq, cut=0)

# Factor scores
fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2, scores="regression")
fa_pa_obq$weights
scores_obq <- predict(fa_pa_obq, data=PFI_cons_ethics_fac)
plot(data.frame(scores_obq))

# Fit statistics and model reliability
summary(fa_pa_obq) # RMSA < 0.08, RMSR = 0.05, TLI > 0.95
Rresid <- resid(fa_pa_obq)
corrplot(Rresid, method="number", number.cex=0.7)

fa.diagram(fa_pa_obq, cut = 0)

PA1 <- c("P1.rc", "P3.rc", "P2.r")
alpha(PFI_cons_ethics_fac[, PA1]) # Cronbach's alpha for PA1

PA2 <- c("P7.r","P5.r")
alpha(PFI_cons_ethics_fac[, PA2]) # Cronbach's alpha for PA2

alpha(PFI_cons_ethics_fac) # Total Cronbach's alpha

omega(PFI_cons_ethics_fac) # Total Omega

# Create rotated factor plot for the reduced PFI scale (Supplementary Figure S1)
loadings <- as.data.frame(unclass(fa_pa_obq$loadings))
loadings$labels <- c("When [target] become more scarce, that is... (RC)",
                     "When people behave kindly towards [target], that is...",
                     "When people harm [target], that is...(RC)",
                     "[Target] and I rise and fall together",
                     "When [target] thrive, I feel good")

PFI_rotplot <- ggplot(data = loadings, aes(x = PA1, y = PA2, label = labels))+
  geom_point(size = 20)+
  geom_text_repel(size = 20, 
                  min.segment.length = 0,
                  position = position_nudge_repel(x = 0.05, y = 0.07))+
  theme_bw()+
  theme(axis.title.x = element_text(face = "bold", size = 60, margin = margin(t = 50, r = 0, b = 0, l = 0))) +
  theme(axis.title.y = element_text(face = "bold", size = 60, margin = margin(t = 0, r = 50, b = 0, l = 0))) +
  theme(axis.text.x = element_text(size = 60, margin = margin(t = 30, r = 0, b = 0, l = 0)))+
  theme(axis.text.y = element_text(size = 60, margin = margin(t = 0, r = 30, b = 0, l = 0)))+
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank())+
  theme(axis.ticks=element_line(size=3))+
  theme(axis.ticks.length=unit(1, "cm"))+
  geom_vline(xintercept = 0, size = 2)+
  geom_hline(yintercept = 0, size = 2)

# Save the plot
tiff("PFI_rotplot.tiff", units = "cm", compression = "lzw",
     width = 50*1.618, height = 50, res = 900)
plot(PFI_rotplot)
dev.off()

# Create factor diagram for the reduced PFI scale (Figure 3) and save the plot
tiff("PFI_plot.tiff", units = "cm", compression = "lzw",
     width = 10*1.618, height = 10, res = 1000)
PFI_plot <- fa.diagram(fa_pa_obq, cut=0, digits = 3, main = NULL, e.size = 0.08, rsize = 2.5, cex = 1)
dev.off()

###### Exploratory factor analyses for conservation ethics scale #####################
# Remove all columns but C1.r - C11.r
PFI_cons_ethics_fac <- PFI_cons_ethics_2[, -c(1:16)]

# Re-code conservation ethics items as numeric
PFI_cons_ethics_fac$C1.r <- as.numeric(PFI_cons_ethics_fac$C1.r)
PFI_cons_ethics_fac$C2.rc <- as.numeric(PFI_cons_ethics_fac$C2.rc)
PFI_cons_ethics_fac$C3.r <- as.numeric(PFI_cons_ethics_fac$C3.r)
PFI_cons_ethics_fac$C4.r <- as.numeric(PFI_cons_ethics_fac$C4.r)
PFI_cons_ethics_fac$C5.rc <- as.numeric(PFI_cons_ethics_fac$C5.rc)
PFI_cons_ethics_fac$C6.rc <- as.numeric(PFI_cons_ethics_fac$C6.rc)
PFI_cons_ethics_fac$C7.r <- as.numeric(PFI_cons_ethics_fac$C7.r)
PFI_cons_ethics_fac$C8.r <- as.numeric(PFI_cons_ethics_fac$C8.r)
PFI_cons_ethics_fac$C9.rc <- as.numeric(PFI_cons_ethics_fac$C9.rc)
PFI_cons_ethics_fac$C10.rc <- as.numeric(PFI_cons_ethics_fac$C10.rc)
PFI_cons_ethics_fac$C11.r <- as.numeric(PFI_cons_ethics_fac$C11.r)

# Check sample size
dim(PFI_cons_ethics_fac) # sample size is > 300

# Check sampling adequacy (Kaiser-Meyer-Olkin)
KMO(cor(PFI_cons_ethics_fac)) # overall KMO = 0.93 and individual KMOs for each item are all > 0.75

# Check summary statistics for each item
barplot(table(PFI_cons_ethics_fac$C1.r))
summary(PFI_cons_ethics_fac$C1.r)
sd(PFI_cons_ethics_fac$C1.r)

barplot(table(PFI_cons_ethics_fac$C2.rc))
summary(PFI_cons_ethics_fac$C2.rc)
sd(PFI_cons_ethics_fac$C2.rc)

barplot(table(PFI_cons_ethics_fac$C3.r))
summary(PFI_cons_ethics_fac$C3.r)
sd(PFI_cons_ethics_fac$C3.r)

barplot(table(PFI_cons_ethics_fac$C4.r))
summary(PFI_cons_ethics_fac$C4.r)
sd(PFI_cons_ethics_fac$C4.r)

barplot(table(PFI_cons_ethics_fac$C5.rc))
summary(PFI_cons_ethics_fac$C5.rc)
sd(PFI_cons_ethics_fac$C5.rc)

barplot(table(PFI_cons_ethics_fac$C6.rc))
summary(PFI_cons_ethics_fac$C6.rc)
sd(PFI_cons_ethics_fac$C6.rc)

barplot(table(PFI_cons_ethics_fac$C7.r))
summary(PFI_cons_ethics_fac$C7.r)
sd(PFI_cons_ethics_fac$C7.r)

barplot(table(PFI_cons_ethics_fac$C8.r))
summary(PFI_cons_ethics_fac$C8.r)
sd(PFI_cons_ethics_fac$C8.r)

barplot(table(PFI_cons_ethics_fac$C9.rc))
summary(PFI_cons_ethics_fac$C9.rc)
sd(PFI_cons_ethics_fac$C9.rc)

barplot(table(PFI_cons_ethics_fac$C10.rc))
summary(PFI_cons_ethics_fac$C10.rc)
sd(PFI_cons_ethics_fac$C10.rc)

barplot(table(PFI_cons_ethics_fac$C11.r))
summary(PFI_cons_ethics_fac$C11.r)
sd(PFI_cons_ethics_fac$C11.r)

# Check correlation between items
cor(PFI_cons_ethics_fac)
R <- cor(PFI_cons_ethics_fac)
round(R, digits=3) # most correlations > 0.3 and all < 0.8

# Test whether the correlation matrix is significantly different from the identity matrix using Bartlett's test
cortest.bartlett(R, n=nrow(PFI_cons_ethics_fac)) # p < 0.05

# Check the determinant to see whether items are perfectly correlated (det = 0)
det(R) # det > 0.00001

# Perform factor extraction
## Compute eigenvalues and use screeplots to determine the number of factors to extract
eig <- eigen(R)
eig$values
plot(eig$values, type="b", main="Screeplot", xlab="Number of Components", ylab="Eigenvalue")
abline(a=1, b=0, col="red")

scree <- scree(PFI_cons_ethics_fac)
scree # screeplot suggests extracting 1 factor

## Compare screeplot results with parallel analysis results
parallel <- fa.parallel(PFI_cons_ethics_fac,fm="pa",fa="fa")
parallel # parallel analysis suggests extracting 2 factors

## Extract 1 factor from initial set of conservation ethics items and examine fit of a one-factor solution
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=1)
fa_pa$e.values
fa_pa

## Extract 2 factors from initial set of conservation ethics items and examine fit of a two-factor solution
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=2)
fa_pa$e.values
fa_pa

## Extract 3 factors from initial set of conservation ethics items and examine fit of a three-factor solution
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=3)
fa_pa$e.values
fa_pa

### Analysis for a two-factor solution

# Print factor loadings
fa_pa$loadings # uses a cut-off of 0.1
print(fa_pa$loadings, cut=NULL) # removes cut-off
fa.sort(fa_pa$loadings) # sorts based on first factor

# Create a factor plot
plot(fa_pa) 
plot(fa_pa, labels=colnames(R), cex=0.8, choose=c(1,2))

# Create a factor diagram to see which factor loads highest onto each item
fa.diagram(fa_pa) # uses a cut-off of 0.3
fa.diagram(fa_pa, cut=0) # removes cut-off
fa.diagram(fa_pa, cut=0, simple=FALSE) # shows full model

# Perform factor rotation (orthogonal - factors are independent, oblique - factors are correlated)
fa_pa_orth <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="varimax", fm="pa", nfactors=2) # orthogonal rotation (varimax)
print(fa_pa_orth$loadings) # factor loadings
plot(fa_pa_orth, labels=colnames(R), cex=0.8, choose=c(1,2)) # factor plot
fa.diagram(fa_pa_orth, cut=0) # factor diagram

fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2) # oblique rotation (oblimin)
print(fa_pa_obq$loadings, cut = NULL) # factor loadings
plot(fa_pa_obq, labels=colnames(R), cex=0.8, choose=c(1,2)) # factor plot
fa.diagram(fa_pa_obq, cut=0) # factor diagram

# Estimate factor scores for both types of rotation
fa_pa_orth <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="varimax", fm="pa", nfactors=2, scores="regression") # orthogonal
fa_pa_orth$weights # score coefficients, note the order
scores_orth <- predict(fa_pa_orth, data=PFI_cons_ethics_fac) # factor scores
plot(data.frame(scores_orth)) # score plot

fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2, scores="regression") # oblique
fa_pa_obq$weights # score coefficients, note the order
scores_obq <- predict(fa_pa_obq, data=PFI_cons_ethics_fac) # factor scores
plot(data.frame(scores_obq)) # score plot

# Assume factors are somewhat correlated, so use oblique rotation
# Check fit statistics and model reliability
summary(fa_pa_obq)
Rresid <- resid(fa_pa_obq)
corrplot(Rresid, method="number", number.cex=0.7)

# Assess total/per-factor internal reliability using Cronbach's alpha and McDonald's omega
fa.diagram(fa_pa_obq, cut=0)

PA1 <- c("C11.r", "C4.r", "C3.r", "C7.r", "C1.r", "C10.rc", "C8.r")
alpha(PFI_cons_ethics_fac[, PA1]) # alpha > 0.8

PA2 <- c("C5.rc", "C6.rc", "C2.rc", "C9.rc")
alpha(PFI_cons_ethics_fac[, PA2])

omega(PFI_cons_ethics_fac) # omega > 0.8

# Repeat exploratory factor analysis with a loading cut-off of 0.6 (following the same process as above)
## Remove C10.rc, C8.r and C9.rc)

PFI_cons_ethics_fac <- subset(PFI_cons_ethics_fac, select = -c(C10.rc, C8.r, C9.rc))

# Check sample size
dim(PFI_cons_ethics_fac)

# Check sampling adequacy (Kaiser-Meyer-Olkin)
KMO(cor(PFI_cons_ethics_fac)) # KMO > 0.8

# Check correlation between items
cor(PFI_cons_ethics_fac) # most correlations > 0.3 and < 0.8
R <- cor(PFI_cons_ethics_fac)
round(R, digits=3)

# Bartlett's test
cortest.bartlett(R, n=nrow(PFI_cons_ethics_fac)) # p < 0.05

# Determinant
det(R) # det > 0.00001

# Factor extraction
## Compute eigenvalues and use screeplots to determine the number of factors to extract
eig <- eigen(R)
eig$values
plot(eig$values, type="b", main="Screeplot", xlab="Number of Components", ylab="Eigenvalue")
abline(a=1, b=0, col="red")

scree <- scree(PFI_cons_ethics_fac)
scree # screeplot suggests extracting 1 factor

## Compare screeplot results with parallel analysis results
parallel <- fa.parallel(PFI_cons_ethics_fac,fm="pa",fa="fa")
parallel # parallel analysis suggests extracting 2 factors

## Extract 2 factors (1-factor solution was not a good fit)
fa_pa <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="none", fm="pa", nfactors=2)
fa_pa$e.values
fa_pa

# Print factor loadings
fa_pa$loadings
print(fa_pa$loadings, cut=NULL)
fa.sort(fa_pa$loadings)

# Factor plot
plot(fa_pa) 
plot(fa_pa, labels=colnames(R), cex=0.8, choose=c(1,2))

# Factor diagram
fa.diagram(fa_pa)
fa.diagram(fa_pa, cut=0)
fa.diagram(fa_pa, cut=0, simple=FALSE)

# Factor rotation
# Assume the factors are somewhat correlated, so use oblique rotation
fa_pa_orth <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="varimax", fm="pa", nfactors=2) # orthogonal rotation
print(fa_pa_orth$loadings)
plot(fa_pa_orth, labels=colnames(R), cex=0.8, choose=c(1,2))
fa.diagram(fa_pa_orth, cut=0) 

fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2) # oblique rotation
print(fa_pa_obq$loadings, cut = NULL)
plot(fa_pa_obq, labels=colnames(R), cex=0.8, choose=c(1,2))
fa.diagram(fa_pa_obq, cut=0)

# Factor scores
fa_pa_obq <- fa(R, n.obs=nrow(PFI_cons_ethics_fac), rotate="oblimin", fm="pa", nfactors=2, scores="regression")
fa_pa_obq$weights
scores_obq <- predict(fa_pa_obq, data=PFI_cons_ethics_fac)
plot(data.frame(scores_obq))

# Fit statistics and model reliability
summary(fa_pa_obq) # RMSA < 0.08, RMSR < 0.05, TLI > 0.95
Rresid <- resid(fa_pa_obq)
corrplot(Rresid, method="number", number.cex=0.7)

fa.diagram(fa_pa_obq, cut=0)

PA1 <- c("C11.r", "C4.r", "C3.r", "C7.r", "C1.r")
alpha(PFI_cons_ethics_fac[, PA1]) # Cronbach's alpha for PA1

PA2 <- c("C5.rc", "C6.rc", "C2.rc")
alpha(PFI_cons_ethics_fac[, PA2]) # Cronbach's alpha for PA2

alpha(PFI_cons_ethics_fac) # Total Cronbach's alpha

omega(PFI_cons_ethics_fac) # Total Omega

# Create rotated factor plot for the reduced conservation ethics scale (Supplementary Figure S2)
loadings <- as.data.frame(unclass(fa_pa_obq$loadings))
loadings$labels <- c("[Target] deserve to be protected from harm",
                     "[Target] should not be treated with care and compassion (RC)",
                     "[Target] deserve to be treated fairly",
                     "I have sympathy for [target]",
                     "Harming [target] is morally right (RC)",
                     "People are entitled to harm [target] (RC)",
                     "Killing [target] is morally wrong",
                     "One of the worst things a person could do is to harm [target]")

Cons_rotplot <- ggplot(data = loadings, aes(x = PA1, y = PA2, label = labels))+
  geom_point(size = 12)+
  geom_text_repel(size = 20, 
                  min.segment.length = 0,
                  position = position_nudge_repel(x = 0.3, y = 0.05))+
  theme_bw()+
  theme(axis.title.x = element_text(face = "bold", size = 60, margin = margin(t = 50, r = 0, b = 0, l = 0))) +
  theme(axis.title.y = element_text(face = "bold", size = 60, margin = margin(t = 0, r = 50, b = 0, l = 0))) +
  theme(axis.text.x = element_text(size = 60, margin = margin(t = 30, r = 0, b = 0, l = 0)))+
  theme(axis.text.y = element_text(size = 60, margin = margin(t = 0, r = 30, b = 0, l = 0)))+
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank())+
  theme(axis.ticks=element_line(size=3))+
  theme(axis.ticks.length=unit(1, "cm"))+
  geom_vline(xintercept = 0, size = 2)+
  geom_hline(yintercept = 0, size = 2)

# Save the plot
tiff("Cons_rotplot.tiff", units = "cm", compression = "lzw",
     width = 50*1.618, height = 50, res = 900)
plot(Cons_rotplot)
dev.off()

# Create factor diagram for the reduced PFI scale (Figure 4) and save the plot
tiff("Cons_plot.tiff", units = "cm", compression = "lzw",
     width = 10*1.618, height = 10, res = 1000)
Cons_plot <- fa.diagram(fa_pa_obq, cut=0, digits = 3, main = NULL, e.size = 0.08, rsize = 2.5, cex = 1)
dev.off()
